<?php

namespace Drupal\eca_push_framework\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\eca\Event\ConditionalApplianceInterface;

/**
 * Provides an abstract base event.
 *
 * @package Drupal\danse\Event
 */
abstract class BaseEvent extends Event implements ConditionalApplianceInterface {

  /**
   * The ID for this event.
   *
   * @var string
   */
  protected string $eventId;

  /**
   * Provides a custom event.
   *
   * @param string $event_id
   *   The ID for this event.
   */
  public function __construct(string $event_id) {
    $this->eventId = $event_id;
  }

  /**
   * {@inheritdoc}
   */
  public function appliesForLazyLoadingWildcard(string $wildcard): bool {
    return ($this->eventId === $wildcard);
  }

  /**
   * {@inheritdoc}
   */
  public function applies(string $id, array $arguments): bool {
    $argument_event_id = isset($arguments['event_id']) ? trim($arguments['event_id']) : '';
    return ($this->eventId === $argument_event_id);
  }

}
